#Stern, Riva and Nielsen (2018) - abiotic factors in seismic lines (light/wind)

## instal necessary packages
if(!require(readr)){install.packages("readr")}
if(!require(car)){install.packages("car")}
if(!require(glmmTMB)){install.packages("glmmTMB")}
if(!require(multcompView)){install.packages("multcompView")}
if(!require(lsmeans)){install.packages("lsmeans")}
if(!require(ggplot2)){install.packages("ggplot2")}

#import csv
light_stern <- read_csv(" #file location# /light_stern.csv")
wind_stern <- read_csv("#file location# /wind_stern.csv")

# Import data
LF <- as.data.frame(light_stern)
WF <- as.data.frame(wind_stern)

# data formatting
LF$site <- as.factor(LF$Site)
WF$site <- as.factor(WF$Site)

# remove treat, based on the experimental design we work just with the directionality
LF$treat <- as.factor(LF$treat)
TF$treat <- as.factor(TF$treat)
WF$treat <- as.factor(WF$treat)

LF$treat_dir <- as.factor(LF$treat_dir)
WF$treat_dir <- as.factor(WF$treat_dir)

# checking
names(LF)
names(WF)

levels(LF$treat_dir)
levels(WF$treat_dir)

# order treatments, from control to larger forest disturbance
LF$treat_dir = factor(LF$treat_dir,levels(LF$treat_dir)[c(5,4,3,2,1,6)])
WF$treat_dir = factor(WF$treat_dir,levels(WF$treat_dir)[c(5,4,3,2,1,6)])
levels(LF$treat_dir)
levels(WF$treat_dir)

# create columns for comparing to 3DEW, 2DEW, Openings
LF$treat_dir3DEW = factor(LF$treat_dir,levels(LF$treat_dir)[c(3,1,2,4,5,6)])
WF$treat_dir3DEW = factor(WF$treat_dir,levels(WF$treat_dir)[c(3,1,2,4,5,6)])
levels(LF$treat_dir3DEW)

LF$treat_dir3DNS = factor(LF$treat_dir,levels(LF$treat_dir)[c(2,1,3,4,5,6)])
WF$treat_dir3DNS = factor(WF$treat_dir,levels(WF$treat_dir)[c(2,1,3,4,5,6)])
levels(LF$treat_dir3DEW)

LF$treat_dir2DEW = factor(LF$treat_dir,levels(LF$treat_dir)[c(5,1,3,2,4,6)])
WF$treat_dir2DEW = factor(WF$treat_dir,levels(WF$treat_dir)[c(5,1,3,2,4,6)])
levels(LF$treat_dir2DEW)

LF$treat_dir2DNS = factor(LF$treat_dir,levels(LF$treat_dir)[c(4,1,3,2,5,6)])
WF$treat_dir2DNS = factor(WF$treat_dir,levels(WF$treat_dir)[c(4,1,3,2,5,6)])
levels(LF$treat_dir2DEW)

LF$treat_dirOpe = factor(LF$treat_dir,levels(LF$treat_dir)[c(6,3,4,1,2,5)])
WF$treat_dirOpe = factor(WF$treat_dir,levels(WF$treat_dir)[c(6,3,4,1,2,5)])
levels(LF$treat_dirOpe)

# inspect data
pairs(LF)
pairs(WF)

par(mfrow = c(1, 1))
plot(LF$light_intensity_sum ~ LF$treat_dir)
plot(LF$light_intensity_sum ~ LF$site)
plot(LF$light_intensity_sum ~ LF$Ht95th)

plot(WF$wind_speed_avg_overall ~ WF$treat_dir)
plot(WF$wind_speed_avg_overall ~ WF$site)
plot(WF$wind_speed_avg_overall ~ WF$Ht95th)

plot(WF$wind_speed_max ~ WF$treat_dir)
plot(WF$wind_speed_max ~ WF$site)
plot(WF$wind_speed_max ~ WF$Ht95th)

#subsets for Treat1 = F,O,L
#light
modelLcomb <- glmmTMB(light_intensity_avg ~ (1|site) + treat1 , data = LF, family = nbinom2(link = "log"))
attributes(logLik(modelLcomb))
summary(modelLcomb)
confint(modelLcomb)
predict(modelLcomb, type="response", se.fit = TRUE)

source(system.file("other_methods","lsmeans_methods.R",package="glmmTMB"))
commp_light <- lsmeans(modelLcomb,pairwise~treat1,adjust="tukey")
cld(commp_light, "boulder_face")
lsmeans(modelLcomb,pairwise~treat1,adjust="tukey")

#wind
modelWcomb <- glmmTMB(wind_speed_avg_overall ~ (1|site) + treat1 , data = WF, family = Gamma(link = "log"))
attributes(logLik(modelWcomb))
summary(modelWcomb)
confint(modelWcomb)
predict(modelWcomb, type="response", se.fit = TRUE)

source(system.file("other_methods","lsmeans_methods.R",package="glmmTMB"))
commp_light <- lsmeans(modelWcomb,pairwise~treat1,adjust="tukey")
cld(commp_light, "boulder_face")
lsmeans(modelWcomb,pairwise~treat1,adjust="tukey")

#wind max
modelWcomb <- glmmTMB(wind_speed_max ~ (1|site) + treat1 , data = WF, family = Gamma(link = "log"))
attributes(logLik(modelWcomb))
summary(modelWcomb)
confint(modelWcomb)
predict(modelWcomb, type="response", se.fit = TRUE)

source(system.file("other_methods","lsmeans_methods.R",package="glmmTMB"))
commp_light <- lsmeans(modelWcomb,pairwise~treat1,adjust="tukey")
cld(commp_light, "boulder_face")
lsmeans(modelWcomb,pairwise~treat1,adjust="tukey")

#light models and outputs
LF_line=LF[LF$treat1=="L",]

modelLF1 <- glmmTMB(light_intensity_avg ~ (1|site) , data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF1))
summary(modelLF1)

modelLF2 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF2))
summary(modelLF2)

modelLF3 <- glmmTMB(light_intensity_avg ~ (1|site) + gap_width , data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF3))
summary(modelLF3)

modelLF4 <- glmmTMB(light_intensity_avg ~ (1|site) + direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF4))
summary(modelLF4)

modelLF5 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th + gap_width , data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF5))
summary(modelLF5)

modelLF6 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th + direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF6))
summary(modelLF6)

modelLF7 <- glmmTMB(light_intensity_avg ~ (1|site) + gap_width + direction , data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF7))
summary(modelLF7)

modelLF8 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th +  gap_width + direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF8))
summary(modelLF8)

modelLF9 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th * gap_width, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF9))
summary(modelLF9)

modelLF10 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th * direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF10))
summary(modelLF10)

modelLF11 <- glmmTMB(light_intensity_avg ~ (1|site) + gap_width * direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF11))
summary(modelLF11)

#the most supported model
modelLF12 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th * gap_width + direction, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF12))
summary(modelLF12)
confint(modelLF12)
predict(modelLF12, type="response", se.fit = TRUE)

modelLF13 <- glmmTMB(light_intensity_avg ~ (1|site) + Ht95th * direction + gap_width, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF13))
summary(modelLF13)

modelLF14 <- glmmTMB(light_intensity_avg ~ (1|site) + gap_width * direction + Ht95th, data = LF_line, family = nbinom2(link = "log"))
attributes(logLik(modelLF14))
summary(modelLF14)

#wind models and outputs
WF_line=WF[WF$treat1=="L",]

modelWF1 <- glmmTMB(wind_speed_avg_overall ~ (1|site) , data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF1))
summary(modelWF1)

modelWF2 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF2))
summary(modelWF2)

modelWF3 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF3))
summary(modelWF3)

modelWF4 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF4))
summary(modelWF4)

modelWF5 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF5))
summary(modelWF5)

modelWF6 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF6))
summary(modelWF6)

#most supported model
modelWF7 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF7))
summary(modelWF7)
confint(modelWF7)
predict(modelWF7, type="response", se.fit = TRUE)
lsmeans(modelWF7,pairwise~treat_dir,adjust="tukey")

modelWF8 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th + gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF8))
summary(modelWF8)

modelWF9 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th * gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF9))
summary(modelWF9)

modelWF10 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th * direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF10))
summary(modelWF10)

modelWF11 <- glmmTMB(wind_speed_avg_overall ~ (1|site) +gap_width * direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF11))
summary(modelWF11)

modelWF12 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th * gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF12))
summary(modelWF12)

modelWF13 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + Ht95th * direction + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF13))
summary(modelWF13)

modelWF14 <- glmmTMB(wind_speed_avg_overall ~ (1|site) + gap_width * direction + Ht95th, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWF14))
summary(modelWF14)


#wind max models
modelWFm1 <- glmmTMB(wind_speed_max ~ (1|site) , data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm1))
summary(modelWFm1)

modelWFm2 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm2))
summary(modelWFm2)

#most supported model
modelWFm3 <- glmmTMB(wind_speed_max ~ (1|site) + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm3))
summary(modelWFm3)
confint(modelWFm3)
predict(modelWFm3, type="response", se.fit = TRUE)
lsmeans(modelWFm3,pairwise~treat_dir,adjust="tukey")

modelWFm4 <- glmmTMB(wind_speed_max ~ (1|site) + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm4))
summary(modelWFm4)

modelWFm5 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm5))
summary(modelWFm5)

modelWFm6 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm6))
summary(modelWFm6)

modelWFm7 <- glmmTMB(wind_speed_max ~ (1|site) + gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm7))
summary(modelWFm7)

modelWFm8 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th + gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm8))
summary(modelWFm8)

modelWFm9 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th * gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm9))
summary(modelWFm9)

modelWFm10 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th * direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm10))
summary(modelWFm10)

modelWFm11 <- glmmTMB(wind_speed_max ~ (1|site) + gap_width * direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm11))
summary(modelWFm11)

modelWFm12 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th * gap_width + direction, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm12))
summary(modelWFm12)

modelWFm13 <- glmmTMB(wind_speed_max ~ (1|site) + Ht95th * direction + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm13))
summary(modelWFm13)

modelWFm14 <- glmmTMB(wind_speed_max ~ (1|site) + gap_width * direction + gap_width, data = WF_line, family = Gamma(link = "log"))
attributes(logLik(modelWFm14))
summary(modelWFm14)

#PLOTS
#Fig 2 violin light avg
ggplot(light_stern,aes(x=treat1,y=light_intensity_avg,fill=treat1))+geom_violin()+geom_boxplot(notch=FALSE,width=0.2)+scale_y_continuous(breaks=scales::pretty_breaks(n=5))+xlab("Treatment")+ylab("Average light intensity (lux)")+scale_fill_brewer(palette="Greens",direction=-1, labels=c("Forests","Seismic Lines","Openings"),name="Treatment")+theme(text=element_text(family="Palatino Linotype"),legend.key.size = unit(3,"cm"),legend.text=element_text(size=50),legend.title=element_text(size=55),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=55),axis.title = element_text(size=55),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.major.x=element_blank(),panel.grid.minor = element_line(color="white"))


# Fig 3 boxplot wind avg
ggplot(wind_stern,aes(x=treat1,y=wind_speed_avg_overall,fill=treat1))+ylim(c(0,3.5))+geom_boxplot(notch=FALSE)+xlab("Treatment")+ylab("Average wind speeds (m/s)")+scale_fill_brewer(palette="Greens",direction=-1, labels=c("Forests","Seismic Lines","Openings"),name="Treatment")+theme(legend.key.size = unit(3,"cm"),text=element_text(family="Palatino Linotype"),legend.text=element_text(size=45),legend.title=element_text(size=50),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=50),axis.title = element_text(size=55),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.major.x=element_blank(),panel.grid.minor = element_line(color="white"))

#Fig 3 boxplot wind max
ggplot(wind_stern,aes(x=treat1,y=wind_speed_max,fill=treat1))+ylim(c(0,3.5))+geom_boxplot(notch=FALSE)+xlab("Treatment")+ylab("Maximum wind speeds (m/s)")+scale_fill_brewer(palette="Greens",direction=-1, labels=c("Forests","Seismic Lines","Openings"),name="Treatment")+theme(legend.key.size = unit(3,"cm"),text=element_text(family="Palatino Linotype"),legend.text=element_text(size=45),legend.title=element_text(size=50),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=50),axis.title = element_text(size=55),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.major.x=element_blank(),panel.grid.minor = element_line(color="white"))

#Fig 4
#light prediction formulas
# e ^ (12.188 + (-0.199x - 0.212canopy height - 0.202 forNS + 0.03*(x*height))
fun2b = function(x) 2.71828 ** ( 12.188 - 0.199*x - 0.202 - (0.212 * 10) + (0.03 * (x * 10)))
fun2c = function(x) 2.71828 ** ( 12.188 - 0.199*x - 0.202 - (0.212 * 20) + (0.03 * (x * 20)))
fun3b = function(x) 2.71828 ** ( 12.188 - 0.199*x - (0.212 * 10) + (0.03 * (x * 10)))
fun3c = function(x) 2.71828 ** ( 12.188 - 0.199*x - (0.212 * 15) + (0.03 * (x * 15)))
#predicted light plots
require(scales)
light_pred <- ggplot(data=data.frame(x=0),mapping=aes(x=x))
light_pred+xlim(2,15)+scale_y_continuous("Light intensity (lux)",limits=c(0,80000),labels=comma)+scale_x_continuous("Gap Width (m)",limits=c(2,10))+stat_function(fun=fun2b,size=2.5,aes(colour="10 m NS",linetype="10 m NS"))+stat_function(fun=fun2c,size=2.5,aes(colour="15 m NS",linetype="15 m NS"))+stat_function(fun=fun3b,size=2.5,aes(colour="10 m EW",linetype="10 m EW"))+stat_function(fun=fun3c,size=2.5,aes(colour="15 m EW",linetype="15 m EW"))+scale_colour_manual("Canopy Height (m)",values=c("10 m NS" ="darkolivegreen","15 m NS" ="darkolivegreen","10 m EW" = "darkolivegreen3","15 m EW" ="darkolivegreen3"))+scale_linetype_manual("Canopy Height (m)",values=c("10 m NS" = "solid", "15 m NS" = "dashed", "10 m EW" = "solid", "15 m EW" = "dashed"))+theme(text=element_text(family="Palatino Linotype"),legend.key.size=unit(5,"lines"),strip.text.x=element_text(size=40),legend.text=element_text(size=40),legend.title=element_text(size=45),plot.title=element_text(size=40,hjust=0.5),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=50),axis.title = element_text(size=50),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.minor = element_line(color="white"),panel.grid.major.x=element_blank())

# Fig 5 wind avg, observed scatterplots + 2 predicted line
wind_pred + xlim(2,10)+scale_y_continuous(limits=c(0,2.5))+scale_x_continuous("Gap Width (m)",limits=c(2,10))+scale_y_continuous("Average Wind Speed (m/s)",limits=c(0,2.5))+stat_function(fun=fun_windavg_EW,size=2.5,aes(colour="EW"))+stat_function(fun=fun_windavg_NS,size=2.5,aes(colour="NS"))+scale_colour_manual("Direction",values=c("EW"="darkolivegreen3","NS"="darkolivegreen"))+geom_point(data=WF_line,size=5,aes(x=gap_width,y=wind_speed_avg_overall,colour=direction))+theme(text=element_text(family="Palatino Linotype"),legend.key.size=unit(7,"lines"),strip.text.x=element_text(size=40),legend.text=element_text(size=40),legend.title=element_text(size=45),plot.title=element_text(size=40,hjust=0.5),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=50),axis.title = element_text(size=50),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.minor = element_line(color="white"),panel.grid.major.x=element_blank())

# Fig 6 wind max observed scatterplot + predicted line
fun_windavg_EW <- function(x) 2.71828 ** (-2.818 + (0.191 * x))
fun_windavg_NS <- function(x) 2.71828 ** (-2.818 - 0.374 + (0.191 * x))
fun1=function(x) 2.71828 ** ( -0.51 + (0.12*x))
wind_pred <- ggplot(data=data.frame(x=0),mapping=aes(x=x))
ggplot(WF_line,aes(x=gap_width,y=wind_speed_max))+geom_point(size=5,colour="darkolivegreen")+scale_y_continuous(limits=c(0,2.5))+scale_x_continuous(limits=c(2,10))+xlab("Gap width of lines (m)")+ylab("Maximum wind speed (m/s)")+theme(text=element_text(family="Palatino Linotype"),legend.text=element_text(size=40),legend.title=element_text(size=45),axis.title.x = element_text(margin=margin(t=20,b=0,r=0,l=0)),axis.title.y = element_text(margin=margin(t=0,b=0,r=20,l=0)),axis.text = element_text(size=50),axis.title = element_text(size=55),panel.background = element_rect(fill="white",colour="black",size=2),panel.grid.major = element_line(color="lightgrey"),panel.grid.minor = element_line(color="white"),panel.grid.major.x=element_blank())+stat_function(fun=fun1,size=3,colour="darkolivegreen")
